@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
+
 
 import sphinx_py3doc_enhanced_theme
 
@@ -17,10 +17,10 @@ extensions = [
 source_suffix = '.rst'
 master_doc = 'index'
 project = 'Aspectlib'
-year = '2014-2020'
+year = '2014-2022'
 author = 'Ionel Cristian Mărieș'
 copyright = '{0}, {1}'.format(year, author)
-version = release = '1.5.1'
+version = release = '2.0.0'
 
 pygments_style = 'trac'
 templates_path = ['.']
@@ -28,17 +28,17 @@ extlinks = {
     'issue': ('https://github.com/ionelmc/python-aspectlib/issues/%s', '#'),
     'pr': ('https://github.com/ionelmc/python-aspectlib/pull/%s', 'PR #'),
 }
-html_theme = "sphinx_py3doc_enhanced_theme"
+html_theme = 'sphinx_py3doc_enhanced_theme'
 html_theme_path = [sphinx_py3doc_enhanced_theme.get_html_theme_path()]
 html_theme_options = {
-    'githuburl': 'https://github.com/ionelmc/python-aspectlib/'
+    'githuburl': 'https://github.com/ionelmc/python-aspectlib/',
 }
 
 html_use_smartypants = True
 html_last_updated_fmt = '%b %d, %Y'
 html_split_index = False
 html_sidebars = {
-   '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
+    '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
 }
 html_short_title = '%s-%s' % (project, version)
 
